@@ -19,7 +19,8 @@ using namespace CalendarSupport;
 class ItemPrivateData
 {
 public:
-    ItemPrivateData(ItemPrivateData *parent) : parentItem(parent)
+    ItemPrivateData(ItemPrivateData *parent)
+        : parentItem(parent)
     {
     }
 
@@ -89,8 +90,7 @@ FreeBusyItemModel::FreeBusyItemModel(QObject *parent)
     qRegisterMetaType<KCalendarCore::Period>("KCalendarCore::Period");
 
     Akonadi::FreeBusyManager *m = Akonadi::FreeBusyManager::self();
-    connect(m, &Akonadi::FreeBusyManager::freeBusyRetrieved, this,
-            &FreeBusyItemModel::slotInsertFreeBusy);
+    connect(m, &Akonadi::FreeBusyManager::freeBusyRetrieved, this, &FreeBusyItemModel::slotInsertFreeBusy);
 
     connect(&d->mReloadTimer, &QTimer::timeout, this, &FreeBusyItemModel::autoReload);
     d->mReloadTimer.setSingleShot(true);
@@ -141,9 +141,8 @@ QVariant FreeBusyItemModel::data(const QModelIndex &index, int role) const
     KCalendarCore::FreeBusyPeriod period = fbitem->freeBusy()->fullBusyPeriods().at(index.row());
     switch (role) {
     case Qt::DisplayRole: // return something to make modeltest happy
-        return QStringLiteral("%1 - %2").
-               arg(QLocale().toString(period.start().toLocalTime(), QLocale::ShortFormat),
-                   QLocale().toString(period.end().toLocalTime(), QLocale::ShortFormat));
+        return QStringLiteral("%1 - %2").arg(QLocale().toString(period.start().toLocalTime(), QLocale::ShortFormat),
+                                             QLocale().toString(period.end().toLocalTime(), QLocale::ShortFormat));
     case FreeBusyItemModel::FreeBusyPeriodRole:
         return QVariant::fromValue(period);
     default:
@@ -169,7 +168,7 @@ int FreeBusyItemModel::rowCount(const QModelIndex &parent) const
 
 int FreeBusyItemModel::columnCount(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
     return 1;
 }
 
@@ -200,7 +199,7 @@ QModelIndex FreeBusyItemModel::parent(const QModelIndex &child) const
         return QModelIndex();
     }
 
-    auto *childData = static_cast<ItemPrivateData *>(child.internalPointer());
+    auto childData = static_cast<ItemPrivateData *>(child.internalPointer());
     ItemPrivateData *parentData = childData->parent();
     if (parentData == d->mRootData) {
         return QModelIndex();
@@ -222,7 +221,7 @@ void FreeBusyItemModel::addItem(const FreeBusyItem::Ptr &freebusy)
     int row = d->mFreeBusyItems.size();
     beginInsertRows(QModelIndex(), row, row);
     d->mFreeBusyItems.append(freebusy);
-    auto *data = new ItemPrivateData(d->mRootData);
+    auto data = new ItemPrivateData(d->mRootData);
     d->mRootData->appendChild(data);
     endInsertRows();
 
@@ -239,7 +238,7 @@ void FreeBusyItemModel::setFreeBusyPeriods(const QModelIndex &parent, const KCal
         return;
     }
 
-    auto *parentData = static_cast<ItemPrivateData *>(parent.internalPointer());
+    auto parentData = static_cast<ItemPrivateData *>(parent.internalPointer());
     int fb_count = list.size();
     int childCount = parentData->childCount();
     QModelIndex first = index(0, 0, parent);
@@ -258,7 +257,7 @@ void FreeBusyItemModel::setFreeBusyPeriods(const QModelIndex &parent, const KCal
     } else if (fb_count > childCount) {
         beginInsertRows(parent, childCount, fb_count - 1);
         for (int i = childCount; i < fb_count; ++i) {
-            auto *childData = new ItemPrivateData(parentData);
+            auto childData = new ItemPrivateData(parentData);
             parentData->appendChild(childData);
         }
         endInsertRows();
