@@ -848,6 +848,11 @@ void CalPrintDay::print(QPainter &p, int width, int height)
             // split out the all day events as they will be printed in a separate box
             KCalendarCore::Event::List alldayEvents, timedEvents;
             for (const KCalendarCore::Event::Ptr &event : qAsConst(eventList)) {
+                if (!event
+                    || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+                    || (mExcludePrivate && event->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
+                    continue;
+                }
                 if (event->allDay()) {
                     alldayEvents.append(event);
                 } else {
@@ -1162,7 +1167,7 @@ void CalPrintWeek::print(QPainter &p, int width, int height)
             drawSplitHeaderRight(p, fromWeek, curWeek, QDate(), width, hh);
             drawTimeTable(p, fromWeek, endLeft, false, mStartTime, mEndTime, weekBox, mIncludeDescription, mExcludeTime, mExcludeConfidential, mExcludePrivate);
             if (mPrintFooter) {
-                drawFooter(p, weekBox1);
+                drawFooter(p, footerBox);
             }
             mPrinter->newPage();
             drawSplitHeaderRight(p, fromWeek, curWeek, QDate(), width, hh);
