@@ -651,11 +651,13 @@ void CalPrintPluginBase::drawSmallMonth(QPainter &p, const QDate &qd, const QRec
     // 3 Pixel after month name, 2 after day names, 1 after the calendar
     double cellHeight = (box.height() - 5) / rownr;
     QFont oldFont(p.font());
-    p.setFont(QFont(QStringLiteral("sans-serif"), int(cellHeight - 2), QFont::Normal));
+    auto newFont = QFont(QStringLiteral("sans-serif"));
+    newFont.setPixelSize(cellHeight);
+    p.setFont(newFont);
 
     // draw the title
     QRect titleBox(box);
-    titleBox.setHeight(int(cellHeight + 1));
+    titleBox.setHeight(p.fontMetrics().height());
     p.drawText(titleBox, Qt::AlignTop | Qt::AlignHCenter, QLocale::system().monthName(month));
 
     // draw days of week
@@ -792,7 +794,6 @@ int CalPrintPluginBase::drawAllDayBox(QPainter &p,
                                       bool excludeConfidential,
                                       bool excludePrivate)
 {
-    KCalendarCore::Event::List::Iterator it;
     int offset = box.top();
     QString multiDayStr;
 
@@ -802,15 +803,13 @@ int CalPrintPluginBase::drawAllDayBox(QPainter &p,
         eventList.prepend(hd);
     }
 
-    it = eventList.begin();
-    while (it != eventList.end()) {
-        KCalendarCore::Event::Ptr currEvent = *it;
-        if ((excludeConfidential && currEvent->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+    for (const KCalendarCore::Event::Ptr &currEvent : qAsConst(eventList)) {
+        if (!currEvent
+            || (excludeConfidential && currEvent->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
             || (excludePrivate && currEvent->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
             continue;
         }
-        if (currEvent && currEvent->allDay()) {
-            // set the colors according to the categories
+        if (currEvent->allDay()) {
             if (expandable) {
                 QRect eventBox(box);
                 eventBox.setTop(offset);
@@ -822,9 +821,6 @@ int CalPrintPluginBase::drawAllDayBox(QPainter &p,
                 }
                 multiDayStr += currEvent->summary();
             }
-            it = eventList.erase(it);
-        } else {
-            ++it;
         }
     }
 
@@ -883,7 +879,8 @@ void CalPrintPluginBase::drawAgendaDayBox(QPainter &p,
         // Adapt start/end times to include complete events
         for (const KCalendarCore::Event::Ptr &event : qAsConst(events)) {
             Q_ASSERT(event);
-            if ((excludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+            if (!event
+                || (excludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
                 || (excludePrivate && event->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
                 continue;
             }
@@ -939,6 +936,11 @@ void CalPrintPluginBase::drawAgendaDayBox(QPainter &p,
     QList<CellItem *> cells;
 
     for (const KCalendarCore::Event::Ptr &event : qAsConst(events)) {
+        if (!event
+            || (excludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+            || (excludePrivate && event->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
+            continue;
+        }
         if (event->allDay()) {
             continue;
         }
@@ -2214,7 +2216,7 @@ void CalPrintPluginBase::drawSplitHeaderRight(QPainter &p, const QDate &fd, cons
     }
 
     title += QString::number(fd.year());
-    p.drawText(0, lineSpacing, width, lineSpacing, Qt::AlignRight | Qt::AlignTop, title);
+    p.drawText(0, lineSpacing + padding(), width, lineSpacing, Qt::AlignRight | Qt::AlignTop, title);
 
     p.setFont(oldFont);
 }
